// import classes
import { Injectable } from '@angular/core';
import { Http, Response, Headers, RequestOptions } from '@angular/http';
import { Observable} from 'rxjs';
import { map } from 'rxjs/operators';
import { catchError } from 'rxjs/operators';
import { Category } from './category';

@Injectable()

// Service for categories data.
export class CategoryService {

    // We need Http to talk to a remote server.
    constructor(private _http: Http) { }

    // Get list of categories from database via api.
    readCategories(): Observable<Category[]>{
        return this._http
            .get("http://localhost/api/category/read.php")
            .pipe(map((res: Response) => res.json().records));
    }

    // Send category data to remote server to create it.
    createCategory(category): Observable<Category>{

        let headers = new Headers({ 'Content-Type': 'application/json' });
        let options = new RequestOptions({ headers: headers });

        return this._http.post(
            "http://localhost/api/category/create.php",
            category,
            options
        ).pipe(map((res: Response) => res.json()));
    }

    // Get a category details from remote server.
    readOneCategory(category_id): Observable<Category>{

        return this._http
            .get("http://localhost/api/category/read_one.php?id="+category_id)
            .pipe(map((res: Response) => res.json()));
    }

    // Send category data to remote server to update it.
    updateCategory(category): Observable<Category>{

        let headers = new Headers({ 'Content-Type': 'application/json' });
        let options = new RequestOptions({ headers: headers });

        return this._http.post(
            "http://localhost/api/category/update.php",
            category,
            options
        ).pipe(map((res: Response) => res.json()));
    }

    // Send category ID to remote server to delete it.
    deleteCategory(category_id){

        let headers = new Headers({ 'Content-Type': 'application/json' });
        let options = new RequestOptions({ headers: headers });

        return this._http.post(
            "http://localhost/api/category/delete.php",
            { id: category_id },
            options
        ).pipe(map((res: Response) => res.json()));
    }

}
